/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005-2006 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.common;

import java.net.URI;
import java.net.URISyntaxException;

/**
 * Constants for the JBI Message Exchange Patterns.
 * 
 * @author ofabre
 * @author gblondelle
 */
public enum MEPConstants {
    IN_ONLY_PATTERN("http://www.w3.org/2004/08/wsdl/in-only"),
    IN_OPTIONAL_OUT_PATTERN("http://www.w3.org/2004/08/wsdl/in-opt-out"),
    IN_OUT_PATTERN("http://www.w3.org/2004/08/wsdl/in-out"),
    ROBUST_IN_ONLY_PATTERN("http://www.w3.org/2004/08/wsdl/robust-in-only");

    private final String nameSpace;

    private MEPConstants(String nameSpace) {
        this.nameSpace = nameSpace;
    }

    public URI value() {
        URI mepURI = null;
        try {
            mepURI = new URI(nameSpace);
        } catch (URISyntaxException e) {
            throw new Error("Unexpected Error in JBI URI namespace syntax", e); // NOPMD
        }
        return mepURI;
    }

    public static MEPConstants valueOf(final URI pattern) {
        MEPConstants result = null;
        for (MEPConstants mep : MEPConstants.values()) {
            if (mep.nameSpace.equals(pattern.toString())) {
                result = mep;
            }
        }
        return result;
    }
}
