/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2006 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.common.bc;

import org.objectweb.petals.component.common.HandlingException;
import org.objectweb.petals.component.common.util.MessageExchangeWrapper;
import org.objectweb.petals.tools.jbicommon.descriptor.Extensions;

/**
 * This interface defines a method that forward internal JBI messages to
 * external services.
 * 
 * @author alouis, ofabre - EBM Websourcing
 * 
 */
public interface JBIListener {

	/**
	 * Called when a JBI message is received on the Component from the JBI
	 * environment. The goal of this method is to call an external service,
	 * related to this JBI message. The address associated with the requested
	 * endpoint is resolved by the abstract component.<br>
	 * <br>
	 * For instance, a ServiceUnit has been deployed on the component, defining
	 * a <code>provides</code> section.<br>
	 * This section defines a relation between the external address
	 * <em>"http://www.enterprise.com/webservices/myService"</em>, and an
	 * Endpoint <em>"myService/jbiMyServiceEndpoint"</em>.<br>
	 * A <em>"myService/jbiMyServiceEndpoint"</em> has been activated on the
	 * JBI environment.<br>
	 * <br>
	 * When a JBI consumer sends in the JBI environment a message to the
	 * <em>"myService/jbiMyServiceEndpoint"</em> endpoint, this component
	 * received the message, and calls the
	 * <code>onJBIMessage(address,endpoint)</code> method.<br>
	 * Then, the method has to send the message to
	 * <em>"http://www.enterprise.com/webservices/myService"</em>.
	 * 
	 * @param address
	 *            the external service address associated to the endpoint given
	 *            in the incoming message exchange.
	 * @param exchange
	 *            the message exchange to process, wrapped to add some util
	 *            methods. Not null
	 * @param extensions
	 *            JBI descriptor extensions. The message exchange targets a
	 *            specific endpoint, this endpoint has been activated during the
	 *            processing of a provides node of a service unit jbi
	 *            descriptor. Theses extensions are the extensions of this
	 *            provides node. Can be null
	 * 
	 * @return boolean used in case of IN_OPTIONAL_OUT_PATTERN. Set to true if
	 *         there's an out message to send, false otherwise. In all cases, a
	 *         <em>DONE</em> status message is returned to the initiator of
	 *         the exchange (except if <code>onJBIMessage()</code> set the
	 *         exchange to <em>ERROR</em>)
	 * @throws HandlingException
	 *             If an error occurs during processing. If the MEP allows it, a
	 *             Fault is automatically returned on the MessageExchange.
	 */
	boolean onJBIMessage(String address, MessageExchangeWrapper exchange,
			Extensions extensions) throws HandlingException;

}
