/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: Logger.java 3:03:53 PM ddesjardins $
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.common.util;

import java.util.Enumeration;
import java.util.ResourceBundle;
import java.util.logging.Filter;
import java.util.logging.Handler;
import java.util.logging.Level;
import java.util.logging.LogRecord;
import java.util.logging.Logger;

/**
 * Logger for the component wraps a java logger. The logger field handles a
 * special logger inheriting from java logger but wrapping methods to monolog
 * logger.
 * 
 * @author ddesjardins - eBMWebsourcing
 */
public class ComponentLogger extends Logger {

    /**
     * Component Name
     */
    private String componentName;

    /**
     * Java logger
     */
    private Logger logger; // NO PMD

    public ComponentLogger(Logger logger, String loggerName,
            String resourceBundleName, String componentName) {
        super(loggerName, resourceBundleName);
        this.logger = logger;
        this.componentName = componentName;
    }

    public void addHandler(Handler handler) throws SecurityException {
        logger.addHandler(handler);
    }

    public void config(String msg) {
        logger.config(msg);
    }

    public void entering(String sourceClass, String sourceMethod) {
        logger.entering(sourceClass, sourceMethod);
    }

    public void entering(String sourceClass, String sourceMethod, Object param1) {
        logger.entering(sourceClass, sourceMethod, param1);
    }

    public void entering(String sourceClass, String sourceMethod,
            Object[] params) {
        logger.entering(sourceClass, sourceMethod, params);
    }

    public boolean equals(Object obj) {
        return logger.equals(obj);
    }

    public void exiting(String sourceClass, String sourceMethod) {
        logger.exiting(sourceClass, sourceMethod);
    }

    public void exiting(String sourceClass, String sourceMethod, Object result) {
        logger.exiting(sourceClass, sourceMethod, result);
    }

    public void fine(String msg) {
        logger.fine("[" + componentName + "] " + convertMsg(msg));
    }

    public void finer(String msg) {
        logger.finer("[" + componentName + "] " + convertMsg(msg));
    }

    public void finest(String msg) {
        logger.finest("[" + componentName + "] " + convertMsg(msg));
    }

    public Filter getFilter() {
        return logger.getFilter();
    }

    public Handler[] getHandlers() {
        return logger.getHandlers();
    }

    public Level getLevel() {
        return logger.getLevel();
    }

    public String getName() {
        return logger.getName();
    }

    public Logger getParent() {
        return logger.getParent();
    }

    public ResourceBundle getResourceBundle() {
        return logger.getResourceBundle();
    }

    public String getResourceBundleName() {
        return logger.getResourceBundleName();
    }

    public boolean getUseParentHandlers() {
        return logger.getUseParentHandlers();
    }

    public int hashCode() {
        return logger.hashCode();
    }

    public void info(String msg) {
        logger.info("[" + componentName + "] " + convertMsg(msg));
    }

    public boolean isLoggable(Level level) {
        return logger.isLoggable(level);
    }

    public void log(Level level, String msg) {
        logger.log(level, "[" + componentName + "] " + convertMsg(msg));
    }

    public void log(Level level, String msg, Object param1) {
        logger.log(level, "[" + componentName + "] " + convertMsg(msg), param1);
    }

    public void log(Level level, String msg, Object[] params) {
        logger.log(level, "[" + componentName + "] " + convertMsg(msg), params);
    }

    public void log(Level level, String msg, Throwable thrown) {
        logger.log(level, "[" + componentName + "] " + convertMsg(msg), thrown);
    }

    public void log(LogRecord record) {
        logger.log(record);
    }

    public void logp(Level level, String sourceClass, String sourceMethod,
            String msg) {
        logger.logp(level, sourceClass, sourceMethod, "[" + componentName
                + "] " + convertMsg(msg));
    }

    public void logp(Level level, String sourceClass, String sourceMethod,
            String msg, Object param1) {
        logger.logp(level, sourceClass, sourceMethod, "[" + componentName
                + "] " + convertMsg(msg), param1);
    }

    public void logp(Level level, String sourceClass, String sourceMethod,
            String msg, Object[] params) {
        logger.logp(level, sourceClass, sourceMethod, "[" + componentName
                + "] " + convertMsg(msg), params);
    }

    public void logp(Level level, String sourceClass, String sourceMethod,
            String msg, Throwable thrown) {
        logger.logp(level, sourceClass, sourceMethod, "[" + componentName
                + "] " + convertMsg(msg), thrown);
    }

    public void logrb(Level level, String sourceClass, String sourceMethod,
            String bundleName, String msg) {
        logger.logrb(level, sourceClass, sourceMethod, bundleName, "["
                + componentName + "] " + convertMsg(msg));
    }

    public void logrb(Level level, String sourceClass, String sourceMethod,
            String bundleName, String msg, Object param1) {
        logger.logrb(level, sourceClass, sourceMethod, bundleName, "["
                + componentName + "] " + convertMsg(msg), param1);
    }

    public void logrb(Level level, String sourceClass, String sourceMethod,
            String bundleName, String msg, Object[] params) {
        logger.logrb(level, sourceClass, sourceMethod, bundleName, "["
                + componentName + "] " + convertMsg(msg), params);
    }

    public void logrb(Level level, String sourceClass, String sourceMethod,
            String bundleName, String msg, Throwable thrown) {
        logger.logrb(level, sourceClass, sourceMethod, bundleName, "["
                + componentName + "] " + convertMsg(msg), thrown);
    }

    public void removeHandler(Handler handler) throws SecurityException {
        logger.removeHandler(handler);
    }

    public void setFilter(Filter newFilter) throws SecurityException {
        logger.setFilter(newFilter);
    }

    public void setLevel(Level newLevel) throws SecurityException {
        logger.setLevel(newLevel);
    }

    public void setParent(Logger parent) {
        logger.setParent(parent);
    }

    public void setUseParentHandlers(boolean useParentHandlers) {
        logger.setUseParentHandlers(useParentHandlers);
    }

    public void severe(String msg) {
        logger.severe("[" + componentName + "] " + convertMsg(msg));
    }

    public void throwing(String sourceClass, String sourceMethod,
            Throwable thrown) {
        logger.throwing(sourceClass, sourceMethod, thrown);
    }

    public String toString() {
        return logger.toString();
    }

    public void warning(String msg) {
        logger.warning("[" + componentName + "] " + convertMsg(msg));
    }

    protected String convertMsg(String msg) {
        String out = msg;
        if (logger.getResourceBundle() != null) {
            Enumeration<String> enumeration = logger.getResourceBundle()
                    .getKeys();
            while (enumeration.hasMoreElements()) {
                String key = enumeration.nextElement();
                if (key.equals(msg)) {
                    out = logger.getResourceBundle().getString(msg);
                    break;
                }
            }
        }
        return out;
    }

}
